==> bitcoin_0.12.1.orig.tar.gz: bitcoin-0.12.1/src/qt/locale/bitcoin_ms_MY.ts <==
<TS language="ms_MY" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Cipta alamat baru</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Salin alamat terpilih ke dalam sistem papan klip</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Salin</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Salin Alamat</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Padam</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Pilih alamat untuk menghantar syiling</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Pilih alamat untuk menerima syiling</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Pilih</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Fail yang dipisahkan dengan koma</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Options...</source>
        <translation>Pilihan</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Alamat</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Salin Alamat</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Balance:</source>
        <translation>Baki</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Fail yang dipisahkan dengan koma</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-0.13.1.tar.gz: bitcoin-0.13.1/src/qt/locale/bitcoin_ms_MY.ts <==
<TS language="ms_MY" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Cipta alamat baru</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Salin alamat terpilih ke dalam sistem papan klip</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Salin</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Padam alamat semasa yang dipilih dari senaraiyang dipilih dari senarai</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>
Alihkan fail data ke dalam tab semasa</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Padam</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Options...</source>
        <translation>Pilihan</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Alamat</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Salin Alamat</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Balance:</source>
        <translation>Baki</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
